@@ -1,7 +1,7 @@
 """
 Type annotations for datapipeline service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/type_defs.html)
 
 Usage::
 
@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence, Union
 
-from typing_extensions import NotRequired
-
 from .literals import OperatorTypeType, TaskStatusType
 
 if sys.version_info >= (3, 9):
@@ -32,7 +30,6 @@ __all__ = (
     "CreatePipelineOutputTypeDef",
     "DeactivatePipelineInputRequestTypeDef",
     "DeletePipelineInputRequestTypeDef",
-    "DescribeObjectsInputDescribeObjectsPaginateTypeDef",
     "DescribeObjectsInputRequestTypeDef",
     "DescribeObjectsOutputTypeDef",
     "DescribePipelinesInputRequestTypeDef",
@@ -43,7 +40,6 @@ __all__ = (
     "GetPipelineDefinitionInputRequestTypeDef",
     "GetPipelineDefinitionOutputTypeDef",
     "InstanceIdentityTypeDef",
-    "ListPipelinesInputListPipelinesPaginateTypeDef",
     "ListPipelinesInputRequestTypeDef",
     "ListPipelinesOutputTypeDef",
     "OperatorTypeDef",
@@ -58,7 +54,6 @@ __all__ = (
     "PollForTaskOutputTypeDef",
     "PutPipelineDefinitionInputRequestTypeDef",
     "PutPipelineDefinitionOutputTypeDef",
-    "QueryObjectsInputQueryObjectsPaginateTypeDef",
     "QueryObjectsInputRequestTypeDef",
     "QueryObjectsOutputTypeDef",
     "QueryTypeDef",
@@ -168,30 +163,6 @@ DeletePipelineInputRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef = TypedDict(
-    "_RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef",
-    {
-        "pipelineId": str,
-        "objectIds": Sequence[str],
-    },
-)
-_OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef = TypedDict(
-    "_OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef",
-    {
-        "evaluateExpressions": bool,
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class DescribeObjectsInputDescribeObjectsPaginateTypeDef(
-    _RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef,
-    _OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredDescribeObjectsInputRequestTypeDef = TypedDict(
     "_RequiredDescribeObjectsInputRequestTypeDef",
     {
@@ -318,14 +289,6 @@ InstanceIdentityTypeDef = TypedDict(
     total=False,
 )
 
-ListPipelinesInputListPipelinesPaginateTypeDef = TypedDict(
-    "ListPipelinesInputListPipelinesPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListPipelinesInputRequestTypeDef = TypedDict(
     "ListPipelinesInputRequestTypeDef",
     {
@@ -493,30 +456,6 @@ PutPipelineDefinitionOutputTypeDef = TypedDict(
     },
 )
 
-_RequiredQueryObjectsInputQueryObjectsPaginateTypeDef = TypedDict(
-    "_RequiredQueryObjectsInputQueryObjectsPaginateTypeDef",
-    {
-        "pipelineId": str,
-        "sphere": str,
-    },
-)
-_OptionalQueryObjectsInputQueryObjectsPaginateTypeDef = TypedDict(
-    "_OptionalQueryObjectsInputQueryObjectsPaginateTypeDef",
-    {
-        "query": "QueryTypeDef",
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class QueryObjectsInputQueryObjectsPaginateTypeDef(
-    _RequiredQueryObjectsInputQueryObjectsPaginateTypeDef,
-    _OptionalQueryObjectsInputQueryObjectsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredQueryObjectsInputRequestTypeDef = TypedDict(
     "_RequiredQueryObjectsInputRequestTypeDef",
     {
